cmd,exp,internal/govulncheck: rename Main to Run

govulncheck.Main is renamed to govulncheck.Run, to avoid confusion since
the word "main" is generally associated with the unimportable main
package.

Change-Id: I4178c1d5ccec5429369dc2a5598c2d2ae45912e3
Reviewed-on: https://go-review.googlesource.com/c/vuln/+/437775
Auto-Submit: Julie Qiu <julieqiu@google.com>
TryBot-Result: Gopher Robot <gobot@golang.org>
Reviewed-by: Jonathan Amsterdam <jba@google.com>
Reviewed-by: Julie Qiu <julieqiu@google.com>
Run-TryBot: Julie Qiu <julieqiu@google.com>
diff --git a/cmd/govulncheck/main.go b/cmd/govulncheck/main.go
index 4c730e1..74e943d 100644
--- a/cmd/govulncheck/main.go
+++ b/cmd/govulncheck/main.go
@@ -73,7 +73,7 @@
 		buildFlags = []string{fmt.Sprintf("-tags=%s", strings.Join(tagsFlag, ","))}
 	}
 
-	govulncheck.Main(govulncheck.Config{
+	govulncheck.Run(govulncheck.Config{
 		Analysis:     mode,
 		OutputFormat: outputType,
 		Patterns:     patterns,
diff --git a/exp/govulncheck/govulncheck.go b/exp/govulncheck/govulncheck.go
index ee67078..a74a380 100644
--- a/exp/govulncheck/govulncheck.go
+++ b/exp/govulncheck/govulncheck.go
@@ -10,7 +10,7 @@
 // Config is the configuration for Main.
 type Config = govulncheck.Config
 
-// Main is the main function for the govulncheck command line tool.
-func Main(cfg Config) {
-	govulncheck.Main(cfg)
+// Run is the main function for the govulncheck command line tool.
+func Run(cfg Config) {
+	govulncheck.Run(cfg)
 }
diff --git a/internal/govulncheck/main.go b/internal/govulncheck/run.go
similarity index 98%
rename from internal/govulncheck/main.go
rename to internal/govulncheck/run.go
index 03ed398..34037a7 100644
--- a/internal/govulncheck/main.go
+++ b/internal/govulncheck/run.go
@@ -41,8 +41,8 @@
 	SourceLoadConfig packages.Config
 }
 
-// Main is the main function for the govulncheck command line tool.
-func Main(cfg Config) {
+// Run is the main function for the govulncheck command line tool.
+func Run(cfg Config) {
 	dbs := []string{"https://vuln.go.dev"}
 	if GOVULNDB := os.Getenv("GOVULNDB"); GOVULNDB != "" {
 		dbs = strings.Split(GOVULNDB, ",")
diff --git a/internal/govulncheck/main_test.go b/internal/govulncheck/run_test.go
similarity index 100%
rename from internal/govulncheck/main_test.go
rename to internal/govulncheck/run_test.go